@@ -2,7 +2,7 @@ context("test-update")
 
 test_that("empty-functions works", {
   # skip_on_cran()
-  expect_silent(x <- ukc_last_update())
+  x <- ukc_last_update()
   expect_true(is.character(x$date))
 
   crimes <- ukc_crime_category()
