@@ -1,7 +1,7 @@
 context("test-neighbourhood-boundary")
 
 test_that("neighbourhood boundaries work", {
-  skip_on_cran()
+  # skip_on_cran()
   borders <- ukc_neighbourhood_boundary("dorset", "55.CB3001")
   expect_length(borders, 2)
 
